@@ -6,24 +6,18 @@
 
 #include "deletejobtest.h"
 
-#include <QTest>
 #include <QDir>
 #include <QFile>
+#include <QSignalSpy>
 #include <QTemporaryDir>
 #include <QTemporaryFile>
-#include <QSignalSpy>
+#include <QTest>
 
 #include <kio/deletejob.h>
 
 QTEST_MAIN(DeleteJobTest)
 
-#define KJOB_NO_ERROR static_cast<int>(KJob::NoError)
-
-void DeleteJobTest::initTestCase()
-{
-    // To avoid a runtime dependency on klauncher
-    qputenv("KDE_FORK_SLAVES", "yes");
-}
+static constexpr int KJOB_NO_ERROR = static_cast<int>(KJob::NoError);
 
 void DeleteJobTest::deleteFileTestCase_data() const
 {
@@ -98,3 +92,5 @@ void DeleteJobTest::createEmptyTestFiles(const QStringList &fileNames, const QSt
 
     QCOMPARE(QDir(path).entryList(QDir::Files).count(), fileNames.size());
 }
+
+#include "moc_deletejobtest.cpp"
