@@ -8,6 +8,7 @@
 #include <QTest>
 
 #include <KIO/StoredTransferJob>
+#include <KMessageWidget>
 #include <KShell>
 #include <QDialog>
 #include <QLineEdit>
@@ -31,32 +32,43 @@
 class KNewFileMenuTest : public QObject
 {
     Q_OBJECT
+
 private Q_SLOTS:
     void initTestCase()
     {
-        QStandardPaths::setTestModeEnabled(true);
 #ifdef Q_OS_UNIX
         m_umask = ::umask(0);
         ::umask(m_umask);
 #endif
-        QVERIFY(m_tmpDir.isValid());
 
         // These have to be created here before KNewFileMenuSingleton is created,
         // otherwise they wouldn't be picked up
-        QDir dir;
+        QStandardPaths::setTestModeEnabled(true);
         m_xdgConfigDir = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
+        // Must not stay in testMode, or user-dirs.dirs does not get parsed
+        // See https://codebrowser.dev/qt6/qtbase/src/corelib/io/qstandardpaths_unix.cpp.html#268
+        QStandardPaths::setTestModeEnabled(false);
+
+        // must use a fake XDG_CONFIG_HOME to change QStandardPaths::TemplatesLocation
+        qputenv("XDG_CONFIG_HOME", m_xdgConfigDir.toUtf8());
+
+        const QString templatesLoc = m_xdgConfigDir + "/test-templates";
+
+        QDir dir;
         QVERIFY(dir.mkpath(m_xdgConfigDir));
         QFile userDirs(m_xdgConfigDir + "/user-dirs.dirs");
         QVERIFY(userDirs.open(QIODevice::WriteOnly));
-        const QString templDir = "XDG_TEMPLATES_DIR=\"" + m_xdgConfigDir + "/test-templates/\"\n";
+        const QString templDir = "XDG_TEMPLATES_DIR=\"" + templatesLoc + "\"\n";
         userDirs.write(templDir.toLocal8Bit());
         userDirs.close();
 
         // Different location than what KNewFileMenuPrivate::slotFillTemplates() checks by default
-        const QString loc = m_xdgConfigDir + '/' + "test-templates/";
-        QVERIFY(dir.mkpath(loc));
 
-        QFile templ(m_xdgConfigDir + "/test-templates" + "/test-text.desktop");
+        QVERIFY(dir.mkpath(templatesLoc));
+
+        // knewfilemenu keeps its data in static variable
+        // The files in template dirs are traversed only once
+        QFile templ(m_xdgConfigDir + "/test-templates/test-text.desktop");
         QVERIFY(templ.open(QIODevice::WriteOnly));
         const QByteArray contents =
             "[Desktop Entry]\n"
@@ -67,6 +79,13 @@ private Q_SLOTS:
 
         templ.write(contents);
         templ.close();
+
+        QDir folderTemplate(templatesLoc + "/my-folder");
+        QVERIFY(folderTemplate.mkdir(folderTemplate.path()));
+
+        QFile templateFile(templatesLoc + "/my-script.py");
+        QVERIFY(templateFile.open(QIODevice::WriteOnly));
+        templateFile.close();
     }
 
     void cleanupTestCase()
@@ -75,6 +94,28 @@ private Q_SLOTS:
         QDir(m_xdgConfigDir + "/test-templates").removeRecursively();
     }
 
+    void openActionText(KNewFileMenu *menu, const QString actionText)
+    {
+        QAction *action = menu;
+        QVERIFY(action);
+        QAction *textAct = nullptr;
+        const QList<QAction *> actionsList = action->menu()->actions();
+        for (QAction *act : actionsList) {
+            if (act->text().contains(actionText)) {
+                textAct = act;
+            }
+        }
+        QVERIFY(textAct != nullptr);
+        if (!textAct) {
+            for (const QAction *act : actionsList) {
+                qDebug() << act << act->text() << act->data();
+            }
+            const QString err = QLatin1String("action with text \"") + actionText + QLatin1String("\" not found.");
+            QVERIFY2(textAct, qPrintable(err));
+        }
+        textAct->trigger();
+    }
+
     // Ensure that we can use storedPut() with a qrc file as input
     // similar to JobTest::storedPutIODeviceFile, but with a qrc file as input
     // (and here because jobtest doesn't link to KIO::FileWidgets, which has the qrc)
@@ -191,23 +232,7 @@ private Q_SLOTS:
         menu.setSelectDirWhenAlreadyExist(true);
         menu.setWorkingDirectory(QUrl::fromLocalFile(m_tmpDir.path()));
         menu.checkUpToDate();
-        QAction *action = &menu;
-        QVERIFY(action);
-        QAction *textAct = nullptr;
-        const QList<QAction *> actionsList = action->menu()->actions();
-        for (QAction *act : actionsList) {
-            if (act->text().contains(actionText)) {
-                textAct = act;
-            }
-        }
-        if (!textAct) {
-            for (const QAction *act : actionsList) {
-                qDebug() << act << act->text() << act->data();
-            }
-            const QString err = QLatin1String("action with text \"") + actionText + QLatin1String("\" not found.");
-            QVERIFY2(textAct, qPrintable(err));
-        }
-        textAct->trigger();
+        openActionText(&menu, actionText);
 
         QDialog *dialog;
         // QTRY_ because a NameFinderJob could be running and the dialog will be shown when
@@ -287,10 +312,9 @@ private Q_SLOTS:
         KNewFileMenu menu(this);
         menu.setWorkingDirectory(QUrl::fromLocalFile(m_tmpDir.path()));
         menu.checkUpToDate();
-        QAction *action = &menu;
-        const auto list = action->menu()->actions();
+        const auto list = menu.menu()->actions();
         auto it = std::find_if(list.cbegin(), list.cend(), [](QAction *act) {
-            return act->text().contains("Custom");
+            return act->text() == QStringLiteral("Custom...");
         });
         QVERIFY(it != list.cend());
         // There is a separator between system-wide templates and the ones
@@ -298,6 +322,80 @@ private Q_SLOTS:
         QVERIFY((*--it)->isSeparator());
     }
 
+    void testParsingSimpleTemplates()
+    {
+        KNewFileMenu menu(this);
+        menu.setWorkingDirectory(QUrl::fromLocalFile(m_tmpDir.path()));
+        menu.checkUpToDate();
+        const auto list = menu.menu()->actions();
+        auto itFolder = std::find_if(list.cbegin(), list.cend(), [](QAction *act) {
+            return act->text() == QStringLiteral("my-folder");
+        });
+        QVERIFY(itFolder != list.cend());
+
+        auto itScript = std::find_if(list.cbegin(), list.cend(), [](QAction *act) {
+            return act->text() == QStringLiteral("my-script");
+        });
+        QVERIFY(itScript != list.cend());
+    }
+
+    void testForbidTildeUsername_data()
+    {
+        QString tildeUsername = QLatin1Char('~') + QDir::home().dirName();
+        QTest::addColumn<QString>("actionText"); // the action we're clicking on
+        QTest::addColumn<QString>("typedFilename"); // what the user is typing
+        QTest::addColumn<bool>("filenameAllowed"); // is the filename allowed, compared to OK button status
+
+        QTest::newRow("text file is ~username.txt") << "Text File" << tildeUsername + ".txt" << true;
+        QTest::newRow("text file is ~username") << "Text File" << tildeUsername << false;
+
+        QTest::newRow("html file is ~username.html") << "HTML File" << tildeUsername + ".html" << true;
+        QTest::newRow("html file is ~username") << "HTML File" << tildeUsername << false;
+
+        QTest::newRow("folder starts with ~") << "Folder..."
+                                              << "~folder1" << true;
+        QTest::newRow("folder name is ~username") << "Folder..." << tildeUsername << false;
+    }
+
+    void testForbidTildeUsername()
+    {
+        QFETCH(QString, actionText);
+        QFETCH(QString, typedFilename);
+        QFETCH(bool, filenameAllowed);
+
+        QWidget parentWidget;
+        KNewFileMenu menu(this);
+        menu.setModal(false);
+        menu.setParentWidget(&parentWidget);
+        menu.setSelectDirWhenAlreadyExist(false);
+        menu.setWorkingDirectory(QUrl::fromLocalFile(m_tmpDir.path()));
+        menu.checkUpToDate();
+        openActionText(&menu, actionText);
+
+        QDialog *dialog;
+        // QTRY_ because a NameFinderJob could be running and the dialog will be shown when
+        // it finishes.
+        QTRY_VERIFY(dialog = parentWidget.findChild<QDialog *>());
+
+        QLineEdit *lineEdit = dialog->findChild<QLineEdit *>();
+        KMessageWidget *msgWidget = dialog->findChild<KMessageWidget *>();
+        QSignalSpy msgSpy(msgWidget, &KMessageWidget::showAnimationFinished);
+        QVERIFY(lineEdit);
+        lineEdit->setText(typedFilename);
+        QVERIFY(msgSpy.wait(1000));
+
+        QDialogButtonBox *buttonsList = dialog->findChild<QDialogButtonBox *>();
+        QVERIFY(buttonsList);
+        auto okButton = buttonsList->button(QDialogButtonBox::Ok);
+        QVERIFY(okButton);
+        auto cancelButton = buttonsList->button(QDialogButtonBox::Cancel);
+        QVERIFY(cancelButton);
+
+        // No need to create new file, we just want to see if the OK button is enabled or not
+        QCOMPARE(okButton->isEnabled(), filenameAllowed);
+        cancelButton->click();
+    }
+
 private:
     QTemporaryDir m_tmpDir;
     QString m_xdgConfigDir;
