@@ -7,17 +7,26 @@
 // This test suite is based on those in ftptest.cpp and uses the same test files.
 
 #include <kio/copyjob.h>
+#include <kio/filesystemfreespacejob.h>
 #include <kio/storedtransferjob.h>
 
 #include <QBuffer>
 #include <QProcess>
+#include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTest>
+#include <qobject.h>
 
 class WebDAVTest : public QObject
 {
     Q_OBJECT
 public:
+    WebDAVTest(const QUrl &url)
+        : QObject()
+        , m_url(url)
+    {
+    }
+
     QUrl url(const QString &path) const
     {
         Q_ASSERT(path.startsWith(QChar('/')));
@@ -27,9 +36,9 @@ public:
         return newUrl;
     }
 
+    QUrl m_url;
     QTemporaryDir m_remoteDir;
     QProcess m_daemonProc;
-    QUrl m_url = QUrl("webdav://localhost");
     static const int port = 30000;
 
 private:
@@ -96,6 +105,40 @@ private Q_SLOTS:
         QCOMPARE(m_daemonProc.state(), QProcess::Running);
     }
 
+    void testFreeSpace()
+    {
+        // check the root folder
+        {
+            auto *job = KIO::fileSystemFreeSpace(url("/"));
+            QSignalSpy spy(job, &KJob::finished);
+            spy.wait();
+            QVERIFY(spy.count() > 0);
+
+            QCOMPARE(job->error(), KJob::NoError);
+            // we can't assume a specific size, so just check that it's non-zero
+            QVERIFY(job->availableSize() > 0);
+            QVERIFY(job->size() > 0);
+        }
+
+        // test freespace on a file, this is unsupported
+        {
+            const QString path("/testFreeSpace");
+            const auto url = this->url(path);
+            const QString remotePath = m_remoteDir.path() + path;
+
+            QByteArray data("testFreeSpace");
+            QFile file(remotePath);
+            QVERIFY(file.open(QFile::WriteOnly));
+            file.write(data);
+            file.close();
+
+            auto *job = KIO::fileSystemFreeSpace(this->url(path));
+            QSignalSpy spy(job, &KJob::finished);
+            spy.wait();
+            QCOMPARE(job->error(), KIO::ERR_UNSUPPORTED_ACTION);
+        }
+    }
+
     void testGet()
     {
         const QString path("/testGet");
@@ -159,8 +202,6 @@ private Q_SLOTS:
 
     void testOverwriteCopy()
     {
-        QSKIP("TODO testOverwriteCopy doesn't pass FIXME");
-
         const QString path("/testOverwriteCopy");
         const auto url = this->url(path);
         const QString remotePath = m_remoteDir.path() + path;
@@ -190,8 +231,6 @@ private Q_SLOTS:
 
     void testOverwriteCopyWithoutFlagFromLocal()
     {
-        QSKIP("TODO testOverwriteCopyWithoutFlagFromLocal doesn't pass FIXME");
-
         const QString path("/testOverwriteCopyWithoutFlag");
         const auto url = this->url(path);
 
@@ -244,5 +283,21 @@ private Q_SLOTS:
     }
 };
 
-QTEST_MAIN(WebDAVTest)
+int main(int argc, char *argv[])
+{
+    QCoreApplication app(argc, argv);
+    app.setAttribute(Qt::AA_Use96Dpi, true);
+
+    WebDAVTest testWedDav(QUrl("webdav://localhost"));
+    auto retWebDav = QTest::qExec(&testWedDav, argc, argv);
+
+    WebDAVTest testDav(QUrl("dav://localhost"));
+    auto retDav = QTest::qExec(&testDav, argc, argv);
+
+    if (retWebDav != 0) {
+        return retWebDav;
+    }
+    return retDav;
+}
+
 #include "webdavtest.moc"
