@@ -9,8 +9,9 @@
 #define KCOREDIRLISTER_P_H
 
 #include "kfileitem.h"
+#include "kmountpoint.h"
 
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
 #include "kdirnotify.h"
 #endif
 
@@ -211,7 +212,7 @@ public:
     void setAutoUpdate(KCoreDirLister *lister, bool enable);
 
     void forgetDirs(KCoreDirLister *lister);
-    void forgetDirs(KCoreDirLister *lister, const QUrl &_url, bool notify);
+    void forgetDirs(KCoreDirLister *lister, const QUrl &_url, bool notify, const KMountPoint::List &possibleMountPoints);
 
     KFileItem findByName(const KCoreDirLister *lister, const QString &_name) const;
     // findByUrl returns a pointer so that it's possible to modify the item.
@@ -323,9 +324,10 @@ private:
         DirItem *dirItem = dirItemForUrl(parentDir);
         if (dirItem) {
             auto it = std::lower_bound(dirItem->lstItems.begin(), dirItem->lstItems.end(), oldUrl);
-            Q_ASSERT(it != dirItem->lstItems.end());
-            dirItem->lstItems.erase(it);
-            dirItem->insert(item);
+            if (it != dirItem->lstItems.end()) {
+                dirItem->lstItems.erase(it);
+                dirItem->insert(item);
+            }
         }
     }
 
@@ -335,8 +337,9 @@ private:
         DirItem *dirItem = dirItemForUrl(parentDir);
         if (dirItem) {
             auto it = std::lower_bound(dirItem->lstItems.begin(), dirItem->lstItems.end(), oldUrl);
-            Q_ASSERT(it != dirItem->lstItems.end());
-            dirItem->lstItems.erase(it);
+            if (it != dirItem->lstItems.end()) {
+                dirItem->lstItems.erase(it);
+            }
         }
     }
 
@@ -406,7 +409,7 @@ private:
         {
             // Note that "entering" means "start watching", and "leaving" means "stop watching"
             // (i.e. it's not when the user leaves the directory, it's when the directory is removed from the cache)
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
             if (entering) {
                 org::kde::KDirNotify::emitEnteredDirectory(url);
             } else {
@@ -501,6 +504,7 @@ private:
         // Remember that this is optional. FTP sites don't return '.' in
         // the list, so they give no root item
         KFileItem rootItem;
+        // The fileitems contained in the directory. Empty when directory is not readable.
         QList<KFileItem> lstItems;
     };
 
@@ -534,27 +538,60 @@ private:
     // this is why we need to remember those files here.
     std::set<KFileItem> pendingRemoteUpdates;
 
+#ifdef WITH_QTDBUS
     // the KDirNotify signals
     OrgKdeKDirNotifyInterface *kdirnotify;
+#endif
 
     struct ItemInUseChange;
 };
 
+enum class ListerStatus : uint8_t {
+    Listing,
+    Holding
+};
+
 // Data associated with a directory url
 // This could be in DirItem but only in the itemsInUse dict...
 struct KCoreDirListerCacheDirectoryData {
-    // A lister can be EITHER in listersCurrentlyListing OR listersCurrentlyHolding
-    // but NOT in both at the same time.
-    // But both lists can have different listers at the same time; this
-    // happens if more listers are requesting url at the same time and
-    // one lister was stopped during the listing of files.
-
-    // Listers that are currently listing this url
-    QList<KCoreDirLister *> listersCurrentlyListing;
-    // Listers that are currently holding this url
-    QList<KCoreDirLister *> listersCurrentlyHolding;
-
     void moveListersWithoutCachedItemsJob(const QUrl &url);
+
+    /*
+     * @returns A list of listers that have the given status.
+     */
+    [[nodiscard]] QList<KCoreDirLister *> listersByStatus(ListerStatus status) const;
+
+    /*
+     * @returns All listers from the container.
+     */
+    [[nodiscard]] QList<KCoreDirLister *> allListers() const;
+
+    /*
+     * Finds a list of KCoreDirListers in the listerContainer and modifies their status,
+     * or inserts the KCoreDirListers to the container with the given status.
+     */
+    void insertOrModifyListers(const QList<KCoreDirLister *> listers, ListerStatus status);
+
+    /*
+     * Modifies or inserts a new KCoreDirLister in the listerContainer with the given status.
+     */
+    void insertOrModifyLister(KCoreDirLister *lister, ListerStatus status);
+
+    void removeLister(KCoreDirLister *lister);
+
+    int totaListerCount();
+
+    int listerCountByStatus(ListerStatus status);
+
+    /*
+     * Checks if given lister with given status is in the container.
+     * @returns If lister with given status is found, true. Otherwise false.
+     */
+    bool contains(KCoreDirLister *lister, ListerStatus status);
+
+private:
+    // A lister can be either in Listing or Holding status.
+    std::unordered_map<KCoreDirLister *, ListerStatus> m_listerContainer;
 };
 
 // This job tells KCoreDirListerCache to emit cached items asynchronously from listDir()
