@@ -66,7 +66,9 @@ class KIOCORE_EXPORT KFileItem
     Q_PROPERTY(bool isRegularFile READ isRegularFile)
 
 public:
-    enum { Unknown = static_cast<mode_t>(-1) };
+    enum {
+        Unknown = static_cast<mode_t>(-1)
+    };
 
     /**
      * The timestamps associated with a file.
@@ -371,7 +373,7 @@ public:
      * @return the time asked for, QDateTime() if not available
      * @see timeString()
      */
-    Q_INVOKABLE QDateTime time(FileTimes which) const;
+    Q_INVOKABLE QDateTime time(KFileItem::FileTimes which) const;
 
     /**
      * Requests the modification, access or creation time as a string, depending
@@ -380,7 +382,7 @@ public:
      * @returns a formatted string of the requested time.
      * @see time
      */
-    Q_INVOKABLE QString timeString(FileTimes which = ModificationTime) const;
+    Q_INVOKABLE QString timeString(KFileItem::FileTimes which = ModificationTime) const;
 
     /**
      * Returns true if the file is a local file.
@@ -560,7 +562,7 @@ public:
 
     /**
      * Returns a MostLocalUrlResult, with the local Url for this item if possible
-     * (otherwise an empty Url), and a bool that is set to @c true if this Url
+     * (otherwise the item url), and a bool that is set to @c true if this Url
      * does represent a local file otherwise @c false.
      *
      * Basically this is an alternative to mostLocalUrl(bool*), that does not use an
@@ -615,9 +617,9 @@ private:
 Q_DECLARE_METATYPE(KFileItem)
 Q_DECLARE_TYPEINFO(KFileItem, Q_RELOCATABLE_TYPE);
 
-inline uint qHash(const KFileItem &item)
+inline size_t qHash(const KFileItem &item, size_t seed = 0)
 {
-    return qHash(item.url());
+    return qHash(item.url(), seed);
 }
 
 /**
