@@ -38,7 +38,6 @@ class KFilePreviewGeneratorPrivate;
  *   resumed. Also in this case the previews for the visible items
  *   are generated first.
  *
- * @since 4.2
  */
 class KIOFILEWIDGETS_EXPORT KFilePreviewGenerator : public QObject
 {
@@ -69,14 +68,6 @@ public:
     void setPreviewShown(bool show);
     bool isPreviewShown() const;
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 3)
-    /**
-     * @deprecated Since 4.3, use KFilePreviewGenerator::updateIcons() instead.
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 3, "Use KFilePreviewGenerator::updateIcons()")
-    void updatePreviews();
-#endif
-
     /**
      * Sets the list of enabled thumbnail plugins.
      * Per default all plugins enabled in the KConfigGroup "PreviewSettings"
@@ -104,7 +95,6 @@ public Q_SLOTS:
      * has been changed by QAbstractItemView::setIconSize(). Note that this method
      * should also be invoked if previews have been turned off, as the icons for
      * cut items must be updated when the icon size has changed.
-     * @since 4.3
      */
     void updateIcons();
 
