@@ -4,7 +4,8 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#pragma once
+#ifndef KURLNAVIGATORPATHSELECTOREVENTFILTER_P_H
+#define KURLNAVIGATORPATHSELECTOREVENTFILTER_P_H
 
 #include <QObject>
 
@@ -26,3 +27,5 @@ protected:
 };
 
 } // namespace KDEPrivate
+
+#endif
